@@ -1,4 +1,4 @@
-/*	$NetBSD: hit.c,v 1.5 1998/11/10 13:01:31 hubertf Exp $	*/
+/*	$NetBSD: hit.c,v 1.7 2003/08/07 09:37:37 agc Exp $	*/
 
 /*
  * Copyright (c) 1988, 1993
@@ -15,11 +15,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -41,7 +37,7 @@
 #if 0
 static char sccsid[] = "@(#)hit.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: hit.c,v 1.5 1998/11/10 13:01:31 hubertf Exp $");
+__RCSID("$NetBSD: hit.c,v 1.7 2003/08/07 09:37:37 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -213,17 +209,17 @@ get_w_damage(obj)
 	const object *obj;
 {
 	char new_damage[12];
-	int to_hit, damage;
+	int tmp_to_hit, tmp_damage;
 	int i = 0;
 
 	if ((!obj) || (obj->what_is != WEAPON)) {
 		return(-1);
 	}
-	to_hit = get_number(obj->damage) + obj->hit_enchant;
+	tmp_to_hit = get_number(obj->damage) + obj->hit_enchant;
 	while (obj->damage[i++] != 'd') ;
-	damage = get_number(obj->damage + i) + obj->d_enchant;
+	tmp_damage = get_number(obj->damage + i) + obj->d_enchant;
 
-	sprintf(new_damage, "%dd%d", to_hit, damage);
+	sprintf(new_damage, "%dd%d", tmp_to_hit, tmp_damage);
 
 	return(get_damage(new_damage, 1));
 }
