@@ -1,4 +1,4 @@
-/*	$NetBSD: level.c,v 1.5 1998/11/10 13:01:32 hubertf Exp $	*/
+/*	$NetBSD: level.c,v 1.7 2003/08/07 09:37:38 agc Exp $	*/
 
 /*
  * Copyright (c) 1988, 1993
@@ -15,11 +15,7 @@
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *	This product includes software developed by the University of
- *	California, Berkeley and its contributors.
- * 4. Neither the name of the University nor the names of its contributors
+ * 3. Neither the name of the University nor the names of its contributors
  *    may be used to endorse or promote products derived from this software
  *    without specific prior written permission.
  *
@@ -41,7 +37,7 @@
 #if 0
 static char sccsid[] = "@(#)level.c	8.1 (Berkeley) 5/31/93";
 #else
-__RCSID("$NetBSD: level.c,v 1.5 1998/11/10 13:01:32 hubertf Exp $");
+__RCSID("$NetBSD: level.c,v 1.7 2003/08/07 09:37:38 agc Exp $");
 #endif
 #endif /* not lint */
 
@@ -261,7 +257,7 @@ make_room(rn, r1, r2, r3)
 	case BIG_ROOM:
 		top_row = get_rand(MIN_ROW, MIN_ROW+5);
 		bottom_row = get_rand(DROWS-7, DROWS-2);
-		left_col = get_rand(0, 10);;
+		left_col = get_rand(0, 10);
 		right_col = get_rand(DCOLS-11, DCOLS-1);
 		rn = 0;
 		goto B;
